//=============================================================================
//  MuseScore
//  Music Composition & Notation
//
//  Chord Names Plugin  
//
//	Copyright (C) 2015 Erik Mundall, erik@mundall.com
//
//  This program is free collaborate-ware--if you're writing scores for hymns or
//  other church music, please share! You can redistribute this and/or modify
//  it under the terms of the GNU General Public License version 2
//  as published by the Free Software Foundation and appearing in
//  the file LICENCE.GPL
//=============================================================================

import QtQuick 2.0
import MuseScore 1.0

MuseScore {
   version: "1.0"
   description: qsTr("This plugin names chords as per your language settings")
   menuPath: "Plugins.Chords." + qsTr("Chord Names") 


function uniq(a) {
    return a.sort().filter(function(item, pos, ary) {
        return !pos || item != ary[pos - 1];
    })
} // end function uniq



   function nameNote (note) {
   		var notename;
         switch (note.tpc) {
            case -1: notename = qsTr("F𝄫"); break;
            case  0: notename = qsTr("C𝄫"); break;
            case  1: notename = qsTr("G𝄫"); break;
            case  2: notename = qsTr("D𝄫"); break;
            case  3: notename = qsTr("A𝄫"); break;
            case  4: notename = qsTr("E𝄫"); break;
            case  5: notename = qsTr("B𝄫"); break;
            case  6: notename = qsTr("F♭") ; break;
            case  7: notename = qsTr("C♭") ; break;

            case  8: notename = qsTr("G♭") ; break;
            case  9: notename = qsTr("D♭") ; break;
            case 10: notename = qsTr("A♭") ; break;
            case 11: notename = qsTr("E♭") ; break;
            case 12: notename = qsTr("B♭") ; break;
            case 13: notename = qsTr("F")  ; break;
            case 14: notename = qsTr("C")  ; break;
            case 15: notename = qsTr("G")  ; break;
            case 16: notename = qsTr("D")  ; break;
            case 17: notename = qsTr("A")  ; break;
            case 18: notename = qsTr("E")  ; break;
            case 19: notename = qsTr("B")  ; break;

            case 20: notename = qsTr("F♯") ; break;
            case 21: notename = qsTr("C♯") ; break;
            case 22: notename = qsTr("G♯") ; break;
            case 23: notename = qsTr("D♯") ; break;
            case 24: notename = qsTr("A♯") ; break;
            case 25: notename = qsTr("E♯") ; break;
            case 26: notename = qsTr("B♯") ; break;
            case 27: notename = qsTr("F𝄪"); break;
            case 28: notename = qsTr("C𝄪"); break;
            case 29: notename = qsTr("G𝄪"); break;
            case 30: notename = qsTr("D𝄪"); break;
            case 31: notename = qsTr("A𝄪"); break;
            case 32: notename = qsTr("E𝄪"); break;
            case 33: notename = qsTr("B𝄪"); break;
            default: notename = qsTr("?")  ; break;
         } // end switch tpc

// change below false to true for courtesy- and microtonal accidentals
// you might need to come up with suitable translations 
// only #, b, natural and possibly also ## seem to be available in UNICODE
         if (false) {
            switch (note.userAccidental) {
               case  0: break;
               case  1: notename = qsTr("♯"); break;
               case  2: notename = qsTr("♭"); break;
               case  3: notename = qsTr("𝄪"); break;
               case  4: notename = qsTr("𝄫"); break;
               case  5: notename = qsTr("natural"); break;
               case  6: notename = qsTr("flat-slash"); break;
               case  7: notename = qsTr("flat-slash2"); break;
               case  8: notename = qsTr("mirrored-flat2"); break;
               case  9: notename = qsTr("mirrored-flat"); break;
               case 10: notename = qsTr("mirrored-flat-slash"); break;
               case 11: notename = qsTr("flat-flat-slash"); break;
               case 12: notename = qsTr("sharp-slash"); break;
               case 13: notename = qsTr("sharp-slash2"); break;
               case 14: notename = qsTr("sharp-slash3"); break;
               case 15: notename = qsTr("sharp-slash4"); break;
               case 16: notename = qsTr("sharp arrow up"); break;
               case 17: notename = qsTr("sharp arrow down"); break;
               case 18: notename = qsTr("sharp arrow both"); break;
               case 19: notename = qsTr("flat arrow up"); break;
               case 20: notename = qsTr("flat arrow down"); break;
               case 21: notename = qsTr("flat arrow both"); break;
               case 22: notename = qsTr("natural arrow down"); break;
               case 23: notename = qsTr("natural arrow up"); break;
               case 24: notename = qsTr("natural arrow both"); break;
               case 25: notename = qsTr("sori"); break;
               case 26: notename = qsTr("koron"); break;
               default: notename = qsTr("?"); break;
            } // end switch userAccidental
         } // end if courtesy- and microtonal accidentals
         return notename
   } // end function
   
   
   function nameChord (chord) {
   
   chord = chord.sort();
   var chordname = "";
   
	 if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) && ((chord[4] == 'E♭') || (chord[4] == 'D♯')) && ((chord[5] == 'E♯') || (chord[5] == 'F')) ) { chordname = qsTr("C♯aug11") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) && ((chord[5] == 'G♯') || (chord[5] == 'A♭')) ) { chordname = qsTr("A♭aug11") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D') || (chord[3] == 'E𝄫')) && ((chord[4] == 'E♭') || (chord[4] == 'D♯')) && ((chord[5] == 'G♭') || (chord[5] == 'F♯')) ) { chordname = qsTr("A♭aug11") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) && ((chord[5] == 'G♯') || (chord[5] == 'A♭')) ) { chordname = qsTr("G♭aug11") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) && ((chord[4] == 'E') || (chord[4] == 'F♭')) && ((chord[5] == 'G♭') || (chord[5] == 'F♯')) ) { chordname = qsTr("G♭aug11") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'C♯') || (chord[3] == 'D♭')) && ((chord[4] == 'D♯') || (chord[4] == 'E♭')) && ((chord[5] == 'E♯') || (chord[5] == 'F')) ) { chordname = qsTr("E♭aug11") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) && ((chord[5] == 'G') || (chord[5] == 'A𝄫')) ) { chordname = qsTr("E♭aug11") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) && ((chord[4] == 'E♯') || (chord[4] == 'F')) && ((chord[5] == 'G♯') || (chord[5] == 'A♭')) ) { chordname = qsTr("D♭aug11") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) && ((chord[5] == 'G') || (chord[5] == 'A𝄫')) ) { chordname = qsTr("D♭aug11") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) && ((chord[4] == 'E♯') || (chord[4] == 'F')) && ((chord[5] == 'F♯') || (chord[5] == 'G♭')) ) { chordname = qsTr("Baug11") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) && ((chord[5] == 'G♭') || (chord[5] == 'F♯')) ) { chordname = qsTr("Baug11") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'F♭') || (chord[4] == 'E')) && ((chord[5] == 'G♯') || (chord[5] == 'A♭')) ) { chordname = qsTr("B♭aug11") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D') || (chord[3] == 'E𝄫')) && ((chord[4] == 'E') || (chord[4] == 'F♭')) && ((chord[5] == 'F') || (chord[5] == 'E♯')) ) { chordname = qsTr("B♭aug11") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) && ((chord[5] == 'G♯') || (chord[5] == 'A♭')) ) { chordname = qsTr("Eaug11") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'B♭') || (chord[2] == 'A♯')) && ((chord[3] == 'D') || (chord[3] == 'E𝄫')) && ((chord[4] == 'E') || (chord[4] == 'F♭')) && ((chord[5] == 'G♭') || (chord[5] == 'F♯')) ) { chordname = qsTr("Eaug11") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'C♯') || (chord[3] == 'D♭')) && ((chord[4] == 'D♯') || (chord[4] == 'E♭')) && ((chord[5] == 'F♭') || (chord[5] == 'E')) ) { chordname = qsTr("Aaug11") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) && ((chord[4] == 'E♭') || (chord[4] == 'D♯')) && ((chord[5] == 'G') || (chord[5] == 'A𝄫')) ) { chordname = qsTr("Aaug11") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) && ((chord[5] == 'G♯') || (chord[5] == 'A♭')) ) { chordname = qsTr("Daug11") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'A♭') || (chord[1] == 'G♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D') || (chord[3] == 'E𝄫')) && ((chord[4] == 'E') || (chord[4] == 'F♭')) && ((chord[5] == 'G♭') || (chord[5] == 'F♯')) ) { chordname = qsTr("Daug11") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'F♭') || (chord[4] == 'E')) && ((chord[5] == 'G♭') || (chord[5] == 'F♯')) ) { chordname = qsTr("Caug11") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) && ((chord[5] == 'G') || (chord[5] == 'A𝄫')) ) { chordname = qsTr("Caug11") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'C♯') || (chord[3] == 'D♭')) && ((chord[4] == 'E♯') || (chord[4] == 'F')) && ((chord[5] == 'E𝄫') || (chord[5] == 'D')) ) { chordname = qsTr("Gaug11") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) && ((chord[5] == 'G') || (chord[5] == 'A𝄫')) ) { chordname = qsTr("Gaug11") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'C♭') || (chord[3] == 'B')) && ((chord[4] == 'D♯') || (chord[4] == 'E♭')) && ((chord[5] == 'E♯') || (chord[5] == 'F')) ) { chordname = qsTr("Faug11") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) && ((chord[5] == 'G') || (chord[5] == 'A𝄫')) ) { chordname = qsTr("Faug11") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) ) { chordname = qsTr("G♭7/6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("G♭7/6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("A♭7/6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("A♭7/6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("G♭M9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("G♭M9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'C♯') || (chord[3] == 'D♭')) && ((chord[4] == 'D♯') || (chord[4] == 'E♭')) ) { chordname = qsTr("E♭7/6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("E♭7/6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("D♭7/6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'B♭') || (chord[2] == 'A♯')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) ) { chordname = qsTr("D♭7/6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("B7/6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'A♭') || (chord[1] == 'G♯')) && ((chord[2] == 'B') || (chord[2] == 'C♭')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("B7/6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) ) { chordname = qsTr("BM9") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("BM9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("B♭7/6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("B♭7/6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("A♭M9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("A♭M9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("D♭M9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) ) { chordname = qsTr("D♭M9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) ) { chordname = qsTr("A7/6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("A7/6") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("E7/6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) && ((chord[4] == 'E') || (chord[4] == 'F♭')) ) { chordname = qsTr("E7/6") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("EM9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("EM9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) && ((chord[4] == 'E𝄫') || (chord[4] == 'D')) ) { chordname = qsTr("E♭M9") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("E♭M9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) && ((chord[4] == 'E𝄫') || (chord[4] == 'D')) ) { chordname = qsTr("B♭M9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D') || (chord[3] == 'E𝄫')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) ) { chordname = qsTr("B♭M9") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'G♯') || (chord[4] == 'A♭')) ) { chordname = qsTr("AM9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'A♭') || (chord[1] == 'G♯')) && ((chord[2] == 'B') || (chord[2] == 'C♭')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) && ((chord[4] == 'E') || (chord[4] == 'F♭')) ) { chordname = qsTr("AM9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) && ((chord[4] == 'E𝄫') || (chord[4] == 'D')) ) { chordname = qsTr("F7/6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) && ((chord[4] == 'F') || (chord[4] == 'E♯')) ) { chordname = qsTr("F7/6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) ) { chordname = qsTr("D7/6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D') || (chord[3] == 'E𝄫')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("D7/6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) ) { chordname = qsTr("DM9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("DM9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'B𝄫') || (chord[3] == 'A')) && ((chord[4] == 'F♭') || (chord[4] == 'E')) ) { chordname = qsTr("C7/6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("C7/6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'F♭') || (chord[4] == 'E')) ) { chordname = qsTr("G7/6") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("G7/6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'F♯') || (chord[4] == 'G♭')) ) { chordname = qsTr("GM9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) && ((chord[4] == 'G♭') || (chord[4] == 'F♯')) ) { chordname = qsTr("GM9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) && ((chord[4] == 'F♭') || (chord[4] == 'E')) ) { chordname = qsTr("FM9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("FM9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) && ((chord[4] == 'F♭') || (chord[4] == 'E')) ) { chordname = qsTr("CM9") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) && ((chord[4] == 'G') || (chord[4] == 'A𝄫')) ) { chordname = qsTr("CM9") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭7sus4") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("A♭7sus4") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("E♭7sus4") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) ) { chordname = qsTr("E♭7sus4") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("B♭7sus4") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("B♭7sus4") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("G♭add9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭add9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("D♭7sus4") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("D♭7sus4") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭add9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) ) { chordname = qsTr("A♭add9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("G♭7sus4") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭7sus4") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("D♭add9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("D♭add9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("Badd9") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Badd9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("B♭dim7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("B♭dim7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("G♭dim7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭dim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("F7sus4") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("F7sus4") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("E♭dim7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("E♭dim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("E♭m7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("E♭m7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("E♭add9") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("E♭add9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("D♭dim7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("D♭dim7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("B7sus4") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("B7sus4") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("B♭m9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) ) { chordname = qsTr("B♭m9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("B♭m7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("B♭m7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("B♭add9") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("B♭add9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("Adim7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Adim7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭dim7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("A♭dim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭m9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'B♭') || (chord[2] == 'A♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("A♭m9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭m7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("A♭m7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Gdim7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Gdim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("G♭M9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭M9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("G♭M7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭M7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("G♭6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("G♭m6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭m6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Edim7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Edim7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Eadd9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Eadd9") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("E♭m9") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("E♭m9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("E♭m6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("E♭m6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("D♭m6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("D♭m6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("C7sus4") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("C7sus4") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("Cdim7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Cdim7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Bdim7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Bdim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) ) { chordname = qsTr("BM9") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) ) { chordname = qsTr("BM9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("BM7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("BM7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("B♭m6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("B♭m6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("A7sus4") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("A7sus4") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Aadd9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("Aadd9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("A♭7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭M9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("A♭M9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭M7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("A♭M7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭m6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("A♭m6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("G7sus4") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("G7sus4") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("G♭m9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'A♭') || (chord[1] == 'G♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭m9") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("G♭m7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭m7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("G♭7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("G♭7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Fdim7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Fdim7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("E7sus4") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("E7sus4") } 
else if (((chord[0] == 'D♯') || (chord[0] == 'E♭')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("EM9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("EM9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) ) { chordname = qsTr("E♭7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("E♭7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("E♭M7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("E♭M7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("D7sus4") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("D7sus4") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Ddim7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Ddim7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("Dadd9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Dadd9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("D♭m9") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) ) { chordname = qsTr("D♭m9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("D♭m7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("D♭m7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("D♭M9") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("D♭M9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("D♭M7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("D♭M7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("D♭6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("D♭6") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("B6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("B6") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Bm6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Bm6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("B♭7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("B♭7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("B♭M9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'D') || (chord[3] == 'E𝄫')) ) { chordname = qsTr("B♭M9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("B♭M7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("B♭M7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("AM9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'A♭') || (chord[1] == 'G♯')) && ((chord[2] == 'B') || (chord[2] == 'C♭')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) ) { chordname = qsTr("AM9") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("AM7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'A♭') || (chord[1] == 'G♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("AM7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("A♭6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("A♭6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("Gadd9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Gadd9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Fm9") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Fm9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Fm7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Fm7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("Fadd9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Fadd9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("EM7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) ) { chordname = qsTr("EM7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("E♭M9") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("E♭M9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) ) { chordname = qsTr("E♭6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("E♭6") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("DM9") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("DM9") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("DM7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("DM7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("D♭7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("D♭7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("Cm9") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'E♭') || (chord[3] == 'D♯')) ) { chordname = qsTr("Cm9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) ) { chordname = qsTr("Cm7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Cm7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Cadd9") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Cadd9") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("Bm9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'D♭') || (chord[3] == 'C♯')) ) { chordname = qsTr("Bm9") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("Bm7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Bm7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("B7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("B7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("B♭6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("B♭6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("A6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("A6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("Am6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Am6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("Gm9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Gm9") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("Gm7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Gm7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("GM9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("GM9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("GM7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("GM7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Gm6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Gm6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("Fm6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Fm6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("Em9") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("Em9") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("E6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("E6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Em6") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Em6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'D♯') || (chord[3] == 'E♭')) ) { chordname = qsTr("Cm6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Cm6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'C♭') || (chord[3] == 'B')) ) { chordname = qsTr("Am9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'C') || (chord[2] == 'B♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Am9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Am7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Am7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("A7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("A7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) && ((chord[3] == 'E♯') || (chord[3] == 'F')) ) { chordname = qsTr("F7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("F7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("FM9") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("FM9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("FM7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("FM7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Em7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("Em7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) && ((chord[3] == 'G♯') || (chord[3] == 'A♭')) ) { chordname = qsTr("E7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("E7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("Dm9") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Dm9") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("Dm7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Dm7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("D7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("D7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♯') || (chord[3] == 'G♭')) ) { chordname = qsTr("D6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'G♭') || (chord[3] == 'F♯')) ) { chordname = qsTr("D6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("Dm6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("Dm6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'B♯') || (chord[2] == 'C')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("C7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("C7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("CM9") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'E') || (chord[3] == 'F♭')) ) { chordname = qsTr("CM9") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'C♭') || (chord[2] == 'B')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("CM7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("CM7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("G7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("G7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("G6") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("G6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) && ((chord[3] == 'E𝄫') || (chord[3] == 'D')) ) { chordname = qsTr("F6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) && ((chord[3] == 'F') || (chord[3] == 'E♯')) ) { chordname = qsTr("F6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) && ((chord[3] == 'F♭') || (chord[3] == 'E')) ) { chordname = qsTr("C6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) && ((chord[3] == 'G') || (chord[3] == 'A𝄫')) ) { chordname = qsTr("C6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) ) { chordname = qsTr("B♭dim7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("B♭dim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭sus") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("A♭sus") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭sus") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("A♭sus") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("G♭sus") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭sus") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭dim7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭dim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("E♭sus") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("E♭sus") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("E♭dim7") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("E♭dim7") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("D♭sus") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("D♭sus") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("D♭sus") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("D♭sus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("D♭dim7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("D♭dim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("B♭sus") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("B♭sus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("B♭dim") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("B♭dim") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("B♭m7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) ) { chordname = qsTr("B♭m7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭dim7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("A♭dim7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭sus") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭sus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("E♭sus") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("E♭sus") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("E♭dim") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("E♭dim") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("E♭m7") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("E♭m7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("Bsus") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("Bsus") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Bdim7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) ) { chordname = qsTr("Bdim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("B♭sus") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("B♭sus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) ) { chordname = qsTr("B♭m6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("B♭m6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("Adim7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("Adim7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭dim") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) ) { chordname = qsTr("A♭dim") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭m7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("A♭m7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Gdim7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Gdim7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) ) { chordname = qsTr("Gdim") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Gdim") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭dim") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭dim") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭M7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭M7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭m6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭m6") } 
else if (((chord[0] == 'E♯') || (chord[0] == 'F')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Fdim7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Fdim7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Edim7") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Edim7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("E♭m6") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("E♭m6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("E♭m") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("E♭m") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("D♭dim") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("D♭dim") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("D♭m6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("D♭m6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("Cdim7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("Cdim7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("Cdim") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("Cdim") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("Bsus") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("Bsus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("BM7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("BM7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("B♭7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) ) { chordname = qsTr("B♭7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("B♭M7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B♭') || (chord[1] == 'A♯')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) ) { chordname = qsTr("B♭M7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("B♭+") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("B♭+") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("B♭m") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("B♭m") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("Adim") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("Adim") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("AM7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'A♭') || (chord[1] == 'G♯')) && ((chord[2] == 'D♭') || (chord[2] == 'C♯')) ) { chordname = qsTr("AM7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("A♭7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭M7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("A♭M7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭m6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("A♭m6") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭m") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("A♭m") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭m7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭m7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭+") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭+") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭m") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭m") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("G♭") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("G♭") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("Fsus") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Fsus") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Fdim") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Fdim") } 
else if (((chord[0] == 'D♯') || (chord[0] == 'E♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Fm7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Fm7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("Esus") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("Esus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Edim") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Edim") } 
else if (((chord[0] == 'D♯') || (chord[0] == 'E♭')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("EM7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("EM7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("E♭7") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("E♭7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("E♭M7") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("E♭M7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Ddim7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Ddim7") } 
else if (((chord[0] == 'E♯') || (chord[0] == 'F')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Ddim") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Ddim") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("DM7") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("DM7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("D♭m7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("D♭m7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("D♭M7") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("D♭M7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("D♭6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("D♭6") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("D♭m") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("D♭m") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("Cm7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("Cm7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Bdim") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Bdim") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("B6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("B6") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Bm6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) ) { chordname = qsTr("Bm6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("B♭6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("B♭6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Asus") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("Asus") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Asus") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("Asus") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("A6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("A6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("Am6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("Am6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭+") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("A♭+") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("A♭6") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("A♭") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("A♭") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Gsus") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Gsus") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Gsus") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Gsus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("Gm7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Gm7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("GM7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'G') || (chord[1] == 'A𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("GM7") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Gm6") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Gm6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("Fsus") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Fsus") } 
else if (((chord[0] == 'E♯') || (chord[0] == 'F')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Fm6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Fm6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Esus") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("Esus") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("E6") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("E6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Em6") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Em6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("E♭+") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("E♭+") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("E♭6") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("E♭6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("E♭") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("E♭") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Dsus") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("Dsus") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Dsus") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Dsus") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("D+") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("D+") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("D♭7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("D♭7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("D♭+") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("D♭+") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("D♭") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("D♭") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Csus") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Csus") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("Csus") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Csus") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("Cm6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("Cm6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Bm7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'D') || (chord[2] == 'E𝄫')) ) { chordname = qsTr("Bm7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("B7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E♭') || (chord[2] == 'D♯')) ) { chordname = qsTr("B7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("B+") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("B+") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("Bm") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("Bm") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("B") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("B") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("B♭") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("B♭") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'B𝄫') || (chord[2] == 'A')) ) { chordname = qsTr("Am7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Am7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'C♯') || (chord[2] == 'D♭')) ) { chordname = qsTr("A7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("A7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("A+") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("A+") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("G+") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("G+") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'A𝄫') || (chord[1] == 'G')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Gm") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Gm") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("F7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("F7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("FM7") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("FM7") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("F+") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("F+") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("Fm") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Fm") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Em7") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Em7") } 
else if (((chord[0] == 'E𝄫') || (chord[0] == 'D')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("E7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("E7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("E+") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("E+") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Dm7") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Dm7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("D7") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("D7") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("D6") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("D6") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Dm6") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Dm6") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("C7") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("C7") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("CM7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("CM7") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("C+") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("C+") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'D♯') || (chord[2] == 'E♭')) ) { chordname = qsTr("Cm") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Cm") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Am") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("Am") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("A") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("A") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("G7") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("G7") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("G6") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("G6") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("F6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("F6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("Em") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("Em") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) && ((chord[2] == 'G♯') || (chord[2] == 'A♭')) ) { chordname = qsTr("E") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'B') || (chord[1] == 'C♭')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("E") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("Dm") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("Dm") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) && ((chord[2] == 'F♯') || (chord[2] == 'G♭')) ) { chordname = qsTr("D") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G♭') || (chord[2] == 'F♯')) ) { chordname = qsTr("D") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("C6") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'E') || (chord[2] == 'F♭')) ) { chordname = qsTr("C6") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) && ((chord[2] == 'E𝄫') || (chord[2] == 'D')) ) { chordname = qsTr("G") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("G") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'B𝄫') || (chord[1] == 'A')) && ((chord[2] == 'E♯') || (chord[2] == 'F')) ) { chordname = qsTr("F") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) && ((chord[2] == 'F') || (chord[2] == 'E♯')) ) { chordname = qsTr("F") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) && ((chord[2] == 'F♭') || (chord[2] == 'E')) ) { chordname = qsTr("C") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) && ((chord[2] == 'G') || (chord[2] == 'A𝄫')) ) { chordname = qsTr("C") } 
else if (((chord[0] == 'D♯') || (chord[0] == 'E♭')) && ((chord[1] == 'G♯') || (chord[1] == 'A♭')) ) { chordname = qsTr("A♭") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) ) { chordname = qsTr("A♭") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) ) { chordname = qsTr("G♭") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'G♭') || (chord[1] == 'F♯')) ) { chordname = qsTr("G♭") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) ) { chordname = qsTr("G♭") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'G♭') || (chord[1] == 'F♯')) ) { chordname = qsTr("G♭") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) ) { chordname = qsTr("E♭") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) ) { chordname = qsTr("E♭") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'G♯') || (chord[1] == 'A♭')) ) { chordname = qsTr("D♭") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) ) { chordname = qsTr("D♭") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) ) { chordname = qsTr("B♭") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) ) { chordname = qsTr("B♭") } 
else if (((chord[0] == 'A♯') || (chord[0] == 'B♭')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) ) { chordname = qsTr("B♭") } 
else if (((chord[0] == 'B♭') || (chord[0] == 'A♯')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) ) { chordname = qsTr("B♭") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'G♯') || (chord[1] == 'A♭')) ) { chordname = qsTr("A♭") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'C') || (chord[1] == 'B♯')) ) { chordname = qsTr("A♭") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) ) { chordname = qsTr("E♭") } 
else if (((chord[0] == 'E♭') || (chord[0] == 'D♯')) && ((chord[1] == 'G') || (chord[1] == 'A𝄫')) ) { chordname = qsTr("E♭") } 
else if (((chord[0] == 'C♯') || (chord[0] == 'D♭')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) ) { chordname = qsTr("D♭") } 
else if (((chord[0] == 'D♭') || (chord[0] == 'C♯')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) ) { chordname = qsTr("D♭") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) ) { chordname = qsTr("B") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'G♭') || (chord[1] == 'F♯')) ) { chordname = qsTr("B") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'D♯') || (chord[1] == 'E♭')) ) { chordname = qsTr("B") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E♭') || (chord[1] == 'D♯')) ) { chordname = qsTr("B") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'C♯') || (chord[1] == 'D♭')) ) { chordname = qsTr("A") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D♭') || (chord[1] == 'C♯')) ) { chordname = qsTr("A") } 
else if (((chord[0] == 'F♭') || (chord[0] == 'E')) && ((chord[1] == 'G♯') || (chord[1] == 'A♭')) ) { chordname = qsTr("E") } 
else if (((chord[0] == 'A♭') || (chord[0] == 'G♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) ) { chordname = qsTr("E") } 
else if (((chord[0] == 'E𝄫') || (chord[0] == 'D')) && ((chord[1] == 'F♯') || (chord[1] == 'G♭')) ) { chordname = qsTr("D") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'G♭') || (chord[1] == 'F♯')) ) { chordname = qsTr("D") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) ) { chordname = qsTr("A") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) ) { chordname = qsTr("A") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) ) { chordname = qsTr("G") } 
else if (((chord[0] == 'D') || (chord[0] == 'E𝄫')) && ((chord[1] == 'G') || (chord[1] == 'A𝄫')) ) { chordname = qsTr("G") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'C♭') || (chord[1] == 'B')) ) { chordname = qsTr("G") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'G') || (chord[1] == 'A𝄫')) ) { chordname = qsTr("G") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) ) { chordname = qsTr("F") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) ) { chordname = qsTr("F") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E♯') || (chord[1] == 'F')) ) { chordname = qsTr("F") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'F') || (chord[1] == 'E♯')) ) { chordname = qsTr("F") } 
else if (((chord[0] == 'C♭') || (chord[0] == 'B')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) ) { chordname = qsTr("E") } 
else if (((chord[0] == 'B') || (chord[0] == 'C♭')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) ) { chordname = qsTr("E") } 
else if (((chord[0] == 'B𝄫') || (chord[0] == 'A')) && ((chord[1] == 'E𝄫') || (chord[1] == 'D')) ) { chordname = qsTr("D") } 
else if (((chord[0] == 'A') || (chord[0] == 'B𝄫')) && ((chord[1] == 'D') || (chord[1] == 'E𝄫')) ) { chordname = qsTr("D") } 
else if (((chord[0] == 'A𝄫') || (chord[0] == 'G')) && ((chord[1] == 'B♯') || (chord[1] == 'C')) ) { chordname = qsTr("C") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'G') || (chord[1] == 'A𝄫')) ) { chordname = qsTr("C") } 
else if (((chord[0] == 'B♯') || (chord[0] == 'C')) && ((chord[1] == 'F♭') || (chord[1] == 'E')) ) { chordname = qsTr("C") } 
else if (((chord[0] == 'C') || (chord[0] == 'B♯')) && ((chord[1] == 'E') || (chord[1] == 'F♭')) ) { chordname = qsTr("C") } 
else { chordname = qsTr("") };

   return chordname;
   
} // end function nameChord

	  // add a staff text element to the top staff at given tick
      // with given text
      function addText(text,tick) {
            var cur = curScore.newCursor();
            var myText = newElement(Element.STAFF_TEXT);
            myText.text = text;
          
            // find a track with a segment at given tick
            var track;
            for (track = 0; track < curScore.ntracks; track++) {
                  cur.track = track;
                  cur.rewind(0);
                  // advance to tick
                  while (cur.segment && cur.tick < tick) {
                        cur.next();
                  } // end while
                  // found tick?
                  if (cur.segment && cur.tick == tick) {
                        // reset to top staff and write text
                        cur.track = 0;
                        cur.add(myText);
                        break;
                  } // end if
            } // end for track
      } // end function addText

      function findAllNotes() {
      	  // CHANGE THE VALUE BELOW TO "0" TO REMOVE ALL REPEATED CHORD NOTATIONS,
      	  // EVEN FOR CHORDS AT THE BEGINNING OF A NEW MEASURE.  SET IT TO "1" TO
      	  // MARK THE CHORD AT LEAST ONCE PER MEASURE, STARTING AT THE BEGINNING.
          var MarkBeginningOfMeasure = 0;
          // SET THE VARIABLE BELOW TO "1" to MARK EVERY CHORD, REGARDLESS OF REPEATS.
          // SET IT TO "0" TO MARK ONLY CHANGING CHORDS (THIS VARIABLE WILL OVERRIDE
          // THE ONE ABOVE IF SET TO "1").
		  var MarkALLChords = 0;
		  
      	  var text  = newElement(Element.STAFF_TEXT);
      	  
      	  // SETUP MAIN CHORD ARRAYS
      	  var chordnotes = [];
			chordnotes[0] = []; // for length
			chordnotes[1] = []; // for notename
      	  var latent = [];
      	    latent[0] = []; // for length
      	    latent[1] = []; // for notename

      	  var note;
      	  var Cname;
      	  var prevCname;
      	  
          var segment = curScore.firstSegment();
          var segCount = 1;
          while (segment) {
          	  var chord = [];
              for (var i = 0; i < curScore.ntracks; i++) {
                  var element = segment.elementAt(i);
                  if (element && element.type == Element.REST) {
						chordnotes[0].push(element.duration);
						chordnotes[1].push("R_ST");
				  }
                  else if (element && element.type == Element.CHORD) {
                      for (var j = 0; j < element.notes.length; j++) {
                          note = element.notes[j];
                          if (note) {
                          	var Nname = nameNote(note);
                          	console.log("note segment: " + segCount +
                                              " track: " + i + " duration: "
                                                          + element.duration +
                                                          " Note: " + 
                                                          nameNote(note));
                                                          
                            ////////////////////////////////////                              
                            // Dealing with exceptions, e.g. chords
                            // with more than one note length (whole note on bass, etc.)
                        
                            	chordnotes[0].push(element.duration);
								chordnotes[1].push(Nname);                      
                          } //end if note
                                                        
                      } //end for j

                  } // end if element CHORD
              } // end for i
              
              // DEAL WITH MISMATCHED CHORD NOTE LENGTHS AND LATENT NOTES
              //1920 ticks = whole note
              // 960 ticks = half note
              // 720 ticks = dotted half note
              // 480 ticks = quarter note <-------
              // 240 ticks = eighth note
			  // 120 ticks = sixteenth note

              // ADD in carry-over notes from earlier segments
              for (var j = 0; j < latent[0].length; j++) {
              		chordnotes[0].push(latent[0][j]);
              		chordnotes[1].push(latent[1][j]);       
              } // end for j
              
                            
			  // Determine shortest note length in current chord
              var shortest = chordnotes[0][0];
              for (var j = 0; j < chordnotes[0].length; j++) {
            		if (shortest > chordnotes[0][j]) { shortest = chordnotes[0][j] };
              } // end for j
              
              //RESET archive array           
      	  		latent[0] = [];
      	  		latent[1] = [];
              
              //ADD new carry-over notes to archives
              for (var j = 0; j < chordnotes[0].length; j++) {
              		if (chordnotes[0][j] > shortest) {
              			var carrynote = (chordnotes[0][j]-shortest); // compute carryover length
              			latent[0].push(carrynote);
              			latent[1].push(chordnotes[1][j]);
              			//console.log("LATENT NOTE: ",chordnotes[0][j],shortest,carrynote, "LATENT ARRAY: ", latent);           		 
              		} // end if chordnotes
              } // end for j

              
              //COMPILE current chord makeup
              chord = [];
              for (var j = 0; j < chordnotes[1].length-1; j++) {
              		if (chordnotes[1][j] != "R_ST") { chord.push(chordnotes[1][j]) };
              } // end for j
              chord = uniq(chord);

			  // RESET chordnotes array
              chordnotes[0] = [];
              chordnotes[1] = [];
            
              Cname = nameChord(chord);             
              console.log("CHORD: ", chord, "Chord NAME: ", Cname);
              
              // PLACE CHORD NOTATIONS ABOVE TOP STAFF
              if (MarkALLChords != 0) {
              		addText(Cname, segment.tick); 
              		prevCname = Cname;
			  } else {              	
               if (prevCname != Cname) {
                if ((Cname != "") || (MarkBeginningOfMeasure == 1)) {
              		addText(Cname, segment.tick); 
              		prevCname = Cname;
              		}
              	}
              };
			  	                  
              segCount++;
              segment = segment.next;
              
          } // end while segment
      } // end function findAllNotes

      onRun: {
            console.log("Hello Chord Names.");
            if (typeof curScore === 'undefined')
                  Qt.quit();

            findAllNotes();
            Qt.quit();
      }
}
